#!/bin/sh

# Licensed Materials - Property of IBM
#
# 5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70 Copyright IBM Corp. 2010
#
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
# Launch the osgiApplicationConsole to allow viewing of active OSGiFrameworks
#
# Launch Arguments
#
# -h The remote host to connect to. Defaults to localhost 
# -o The remote port to connect to.
# -u The userid to connect to the secured wsadmin system.
# -p The password to connect to the secured wsadmin system.
#

# set up the usage string.
usage="osgiApplicationConsole -h <hostname> -o <port> -u <userid> -p <password>"
# iterate over the properties setting the wsadmin values for the relevant property
while getopts :h:o:u:p: arguments
do
  case $arguments in
    # If we have -h then set the host value
    h) host="-host $OPTARG";;
    # if we have -o then set the port value 
    o) port="-port $OPTARG";;
    # If we have -u then set the user value
    u) user="-user $OPTARG";;
    # if we have -p then set the password value
    p) pwd="-password $OPTARG";;
    # All other options are invalid. Display error and usage.
    \?) echo "Invalid argument passed"
        echo "$usage";;
  esac
done

# get the current directory
bindir=`dirname $0`

# Set the aries dir.
ariesDir="${bindir}/../osgiappbundles/com.ibm.ws.osgi.applications"

# Find the osgi jar that we need for the python script
osgiJar=`ls ${ariesDir}/aries/org.eclipse.osgi*.jar`

# Set the admin jar which contains all the messages for the script.
adminJar="${ariesDir}/com.ibm.ws.eba.admin.jar"

# Finally Call wsadmin passing in the python script and the osgi jar on the wsadmin classpath
${bindir}/../../../bin/wsadmin.sh -lang jython -profile ${bindir}/../scriptLibraries/osgi/osgiApplicationConsole.py -wsadmin_classpath ${osgiJar}:${adminJar} ${host} ${port} ${user} ${pwd}
