/*
 * @start_prolog@
 * ============================================================================
 *  Licensed Materials - Property of IBM
 *  
 *  5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70
 *  
 *  Copyright IBM Corp. 2009
 * ============================================================================
 * @end_prolog@
 * 
 * Change activity:
 * 
 * Issue       Date        Name           Description
 * ----------- ----------- -------------- ------------------------------------
 */
package com.ibm.ws.eba.example.blabber.persistence;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;

import com.ibm.ws.eba.example.blabber.persistence.entity.Post;
import com.ibm.ws.eba.example.blabber.persistence.entity.UserInfo;
import com.ibm.ws.eba.example.blabber.persistence.spi.BlabberUserInterface;

public class BlabberImpl implements BlabberUserInterface {
  private static final String searchUserNameQuery = "select u from UserInfo u WHERE u.username LIKE ?1";
  private static final String uniqueEmailAddressQuery = "select u from UserInfo u where u.emailAddress = ?1";
  private static final String getPostsVisibleToUserQuery = "SELECT p from Post p WHERE p.author.username = ?1 OR EXISTS (SELECT u from UserInfo u WHERE u.username = ?1 AND p.author MEMBER u.tracking) ORDER BY p.timestamp DESC";
  private static final String getMyPostsQuery = "select p from Post p where p.author.username = ?1";
  private EntityManager em;

  @PersistenceContext(unitName = "blabber")
  public void setEntityManager(EntityManager e) {
    
    em = e;
  }

  @SuppressWarnings("unchecked")
  public boolean checkEMailAddressUniqueness(String emailAddress) {
    
    boolean result = false;
    Query q = em.createQuery(uniqueEmailAddressQuery);
    q.setParameter(1, emailAddress);
    
    List<UserInfo> users = q.getResultList();

    if (users.isEmpty()) {
      result = true;
    }

    return result;
  }

  public boolean checkUsernameUniqueness(String username) {
    
    boolean result = false;
    UserInfo user = em.find(UserInfo.class, username);

    if (user == null) {
      result = true;
    }

    return result;
  }

  public List<Post> getMentionsOfUser(String username) {

    List<Post> result = new ArrayList<Post>();
    List<Post> posts = getPostsForUserProfile(username);
    Iterator<Post> postIterator = posts.iterator();

    while (postIterator.hasNext()) {
      Post post = postIterator.next();
      if (post.getContent().contains(username)) {
        result.add(post);
      }
    }

    return result;
  }

  @SuppressWarnings("unchecked")
  public List<Post> getPostsByUser(String username) {
    
    Query q = em.createQuery(getMyPostsQuery);
    q.setParameter(1, username);
    List<Post> result = q.getResultList();

    return result;
  }

  @SuppressWarnings("unchecked")
  public List<Post> getPostsForUserProfile(String username) {

    Query q = em.createQuery(getPostsVisibleToUserQuery);
    q.setParameter(1, username);
    List<Post> result = q.getResultList();

    return result;
  }

  public void postContent(String userName, String content) {
      
    UserInfo u = em.find(UserInfo.class, userName);
    Post post = new Post(u, content);
    em.persist(post);
  }

  @SuppressWarnings("unchecked")
  public List<UserInfo> searchUsername(String usernameFilter) {
    
    usernameFilter = usernameFilter.replaceAll("\\*", "%");
    usernameFilter += "%";

    Query q = em.createQuery(searchUserNameQuery);
    q.setParameter(1, usernameFilter);
    List<UserInfo> users = q.getResultList();

    return users;
  }

  public boolean startTracking(String userThatWillTrack, String userToBeTracked) {
    
    boolean result = false;
    UserInfo user = em.find(UserInfo.class, userThatWillTrack);
    UserInfo usertoAdd = em.find(UserInfo.class, userToBeTracked);

    if (user != null) {
      Set<UserInfo> trackedUsers = user.getTracking();
      if (trackedUsers != null) {
        if (usertoAdd != null) {
          trackedUsers.add(usertoAdd);
          result = true;
        }
      }
    }
   
    return result;
  }

  public boolean stopTracking(String userThatTracks, String userToStopTracking) {
    
    UserInfo user = em.find(UserInfo.class, userThatTracks);
    UserInfo userToRemove = em.find(UserInfo.class, userToStopTracking);

    boolean result = (user == null || userToRemove == null) ? false : user
        .getTracking().remove(userToRemove);

    return result;
  }

  public boolean logon(String username, String password) {
    
    boolean result = false;
    UserInfo user = em.find(UserInfo.class, username);

    if (user != null && user.getPassword().equals(password)) {
      result = true;
    }

    return result;
  }

  public boolean registerUser(String username, String password,
      String emailAddress, int avatar) {
    
    boolean result = true;
    UserInfo user = new UserInfo(username, password, emailAddress, avatar);
    em.persist(user);
    return result;
  }

  public boolean isTracking(String tracker, String tracked) {

    UserInfo trackerInfo = em.find(UserInfo.class, tracker);
    boolean found = false;
    for (UserInfo user : trackerInfo.getTracking()) {
      if (user.getUsername().equals(tracked)) {
        found = true;
        break;
      }
    }
    return found;
  }

  public Set<UserInfo> getTrackedUsers(String username) {
    
    UserInfo trackerInfo = em.find(UserInfo.class, username);
    Set<UserInfo> trackedUsers = new HashSet<UserInfo>();
    trackedUsers.addAll(trackerInfo.getTracking());
    
    return trackedUsers;
  }

  public int getUserAvatar(String username) {
    
    UserInfo user = em.find(UserInfo.class, username);
    return user.getAvatar();
  }

}
