/*
 * @start_prolog@
 * ============================================================================
 *  Licensed Materials - Property of IBM
 *  
 *  5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70
 *  
 *  Copyright IBM Corp. 2009
 * ============================================================================
 * @end_prolog@
 * 
 * Change activity:
 * 
 * Issue       Date        Name           Description
 * ----------- ----------- -------------- ------------------------------------
 * 4544        27-Nov-2009 mnuttall@uk    Fix findbugs issue with getTimeStamp()
 */
package com.ibm.ws.eba.example.blabber.persistence.entity;

import java.text.SimpleDateFormat;
import java.util.Date;

import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.ManyToOne;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

/**
 * Entity class representing a post
 */
@Entity
public class Post
{
   
    // Many posts to one user
    @ManyToOne(fetch=FetchType.EAGER, optional=false)
	private UserInfo author = null;
	private String content = null;
	@Temporal(TemporalType.TIMESTAMP)
	private Date timestamp = null;
	
	public Post() {}
	
	@Override
	public String toString() { 
		return "Post{ author=" + author + " content=`" + content + "` timestamp=" + timestamp.toString() + "}";
	}
	
	public Post(UserInfo author, String content)
	{
		this.author = author;
		this.content = content;
		this.timestamp = new Date();
	}
	
	public UserInfo getAuthor()
	{
		return author;
	}
	
	public String getContent()
	{
		return content;
	}
	
	public String getTimeStampAsString()
	{
		return new SimpleDateFormat("dd/MM/yyyy").format(timestamp);
	}

	public Date getTimeStamp()
	{
		return new Date(timestamp.getTime());
	}

}
