/*
 * @start_prolog@
 * ============================================================================
 *  Licensed Materials - Property of IBM
 *  
 *  5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70
 *  
 *  Copyright IBM Corp. 2009
 * ============================================================================
 * @end_prolog@
 * 
 * Change activity:
 * 
 * Issue       Date        Name           Description
 * ----------- ----------- -------------- ------------------------------------
 */
package com.ibm.ws.eba.example.blabber.persistence.entity;

import java.util.HashSet;
import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.Id;
import javax.persistence.ManyToMany;

/**
 * An entity class representing user information
 */
@Entity
public class UserInfo
{
    // use the username as the key in the database
	@Id
	@Column(nullable=false)
	private String username;	
	
	@Column(nullable=false)
	private String password;
	
	@Column(nullable=false)	
	private String emailAddress;
	private int avatar;
	
	@ManyToMany(fetch=FetchType.LAZY)
	private Set<UserInfo> tracking;
	
	@Override
	public String toString() { 
		return "UserInfo{ username=" + username + " password=" + password
				+ " avatar = " + avatar + " email=" + emailAddress + "}";
	}
	
	public UserInfo() {}
	
	public UserInfo(String username, String password, String emailAddress, int avatar)
	{
		this.username = username;
		this.avatar = avatar;
		this.password = password;
		this.emailAddress = emailAddress;
		this.tracking = new HashSet<UserInfo>();
	}
	
	public String getUsername()
	{
		return username;
	}
	
	public String getPassword()
	{
		return password;
	}
	
	public String getEmailAddress()
	{
		return emailAddress;
	}
	
	public int getAvatar()
	{
		return avatar;
	}
	
	/**
	 * Retrieve the tracking data for this user
	 * @return a Set<UserInfo> of users this user is tracking
	 */
	public Set<UserInfo> getTracking()
	{
	  return tracking;
	}
	
}
