/*
 * @start_prolog@
 * ============================================================================
 *  Licensed Materials - Property of IBM
 *  
 *  5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70
 *  
 *  Copyright IBM Corp. 2009
 * ============================================================================
 * @end_prolog@
 * 
 * Change activity:
 * 
 * Issue       Date        Name           Description
 * ----------- ----------- -------------- ------------------------------------
 */
package com.ibm.ws.eba.example.blabber;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.DateFormat;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ibm.json.java.JSONArray;
import com.ibm.json.java.JSONObject;
import com.ibm.ws.eba.example.blabber.persistence.entity.Post;

public class GetPosts extends HttpServlet
{
	private static final long serialVersionUID = 4346008433279296520L;

	@Override
	public void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException
	{	
			// GET action requested...
			PrintWriter out = response.getWriter();
			response.setContentType(Constants._CONTENT_TYPE);

			JSONObject result = new JSONObject();
			result.put(Constants._IDENTIFIER, Constants._TIMESTAMP);
			result.put(Constants._LABEL, Constants._UPDATE);

			JSONArray posts = new JSONArray();
			result.put("items", posts);

			String username = request.getParameter(Constants._USER_NAME_PARM);
			boolean forUserProfile = request.getParameter(Constants._FOR_USER_PROFILE_PARM) != null;
			if (username == null)
			{
				// If no user name was provided, return an empty object...
			}
			else
			{
				if (forUserProfile)
				{
					// If the "forUserProfile" parameter passed then we need to return all posts
					// for everyone that requested user is interested in...
					for (Post post : BlabberUtils.getBlabberService().getPostsForUserProfile(username))
					{
						posts.add(createPost(post));
					}
				}
				else
				{
					// If the "forUserProfile" parameter is NOT passed then we just want to return
					// the posts made by the requested user...
					for (Post post : BlabberUtils.getBlabberService().getPostsByUser(username))
					{
						posts.add(createPost(post));
					}
				}
			}

			out.print(result.serialize());
			out.flush();
	
	}


	private JSONObject createPost(Post post)
	{
		JSONObject jsonPost = new JSONObject();
		jsonPost.put(Constants._IMAGE, post.getAuthor().getAvatar());
		jsonPost.put(Constants._USER_NAME_PARM, post.getAuthor().getUsername());
	    DateFormat df = DateFormat.getDateTimeInstance(DateFormat.LONG, DateFormat.LONG);
		jsonPost.put(Constants._TIMESTAMP, df.format(post.getTimeStamp()));
		jsonPost.put(Constants._UPDATE, post.getContent());
		return jsonPost;
	}

}
