/*
 * @start_prolog@
 * ============================================================================
 *  Licensed Materials - Property of IBM
 *  
 *  5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70
 *  
 *  Copyright IBM Corp. 2009
 * ============================================================================
 * @end_prolog@
 * 
 * Change activity:
 * 
 * Issue       Date        Name           Description
 * ----------- ----------- -------------- ------------------------------------
 */
package com.ibm.ws.eba.example.blabber;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ibm.json.java.JSONObject;

public class Registration extends HttpServlet
{
	private static final long serialVersionUID = 6972614351822550132L;
	
	@Override
	public void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException
	{
			// GET action requested...
			/*
			 * This method will need to handle the following asynchronous requests... 
			 * 
			 * 1. Is the requested user name already in use? 
			 * 2. Is the requested e-mail address already assigned
			 *    to an existing user?
			 */
			PrintWriter out = response.getWriter();
			response.setContentType(Constants._CONTENT_TYPE);

			JSONObject result = new JSONObject();

			// Initially just hard-code some data to ensure that the panel code works and then
			// plug in to the business logic later.
			if (request.getParameter(Constants._VALIDATE_USER_NAME_PARM) != null)
			{
				// A request has been made to check whether or not the user name is unique...
				String userName = request.getParameter(Constants._SUGGESTED_USER_NAME);
				if (userName == null)
				{
					// A request has been made to validate a user name, but no user name has
					// been supplied.
					result.put(Constants._IS_VALID_ATTR, false);
				}
				else
				{
					// Validate the user name supplied...
					result.put(Constants._IS_VALID_ATTR, BlabberUtils.getBlabberService().checkUsernameUniqueness(userName));
				}
			}
			else if (request.getParameter(Constants._VALIDATE_EMAIL_PARM) != null)
			{
				// A request has been made to check whether or not the e-mail address has been previously assigned...
				String emailAddress = request.getParameter(Constants._SUGGESTED_EMAIL);
				if (emailAddress == null)
				{
					// A request has been made to validate an e-mail address, but no e-mail address has been supplied.
					result.put(Constants._IS_VALID_ATTR, false);
				}
				else
				{
					// Validate the e-mail address supplied...
					result.put(Constants._IS_VALID_ATTR, BlabberUtils.getBlabberService().checkEMailAddressUniqueness(emailAddress));
				}
			}
			else
			{
				// There are no other asynchronous requests that can be processed. No action required.
			}

			// Output the JSON result...
			out.print(result.serialize());
			out.flush();

	}
	
	
	@Override
	public void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException
	{
			// POST action requested...
			/*
			 * This method will need to handle registration requests. Although the user data should have been asynchronously validation to
			 * ensure that the requested data is valid, it is possible that a registration may take place between asynchronous validation and
			 * actual registration so this method needs to be able to handle registration failures.
			 */
			PrintWriter out = response.getWriter();
			response.setContentType(Constants._CONTENT_TYPE);

			JSONObject result = new JSONObject();
			String username = request.getParameter(Constants._USER_NAME_PARM);
			String password = request.getParameter(Constants._PASSWORD_PARM);
			String emailAddress = request.getParameter(Constants._EMAIL_ADDRESS_PARM);
			String avatarStr = request.getParameter(Constants._AVATAR_PARM);
			if (BlabberUtils.getBlabberService().registerUser(username, password, emailAddress, Integer.parseInt(avatarStr)))
			{
				result.put(Constants._SUCCESS, true);
				request.getSession().setAttribute(Constants._SIGNED_ON_USER_NAME, username);
			}
			else
			{
				result.put(Constants._SUCCESS, false);
				result.put(Constants._MESSAGE, "Registration failed");
			}

			out.print(result.serialize());
			out.flush();
	}
}
