import sys
## 
##  Licensed Materials - Property of IBM
##  
##  5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70
##  
##  Copyright IBM Corp. 2009
##
#######################################################################

def showUsage():
    print ""
    print "--- ERROR: Incorrect usage."
    print ""
    print "Usage: wsadmin -f blogSampleInstall.py [setupOnly|fullInstall] serverName nodeName [blogEBA] [JSON4JBundle]" 
    print ""
    print "Where:"
    print ""
    print "  setupOnly   = only run the datasource creation"
    print "  fullInstall = datasource creation and application install"
    print ""
    print "  serverName  = application server name for the jndi scope"
    print "  nodeName    = node name associated with the server"
    print "  blogEBA     = the path to the blog sample .eba file (fullInstall option only)"
    print "  JSON4JBundle = the path to the JSON4J bundle file (fullInstall option only)"
    print ""
    print ""
    sys.exit()


#######################################################################

if (len(sys.argv) < 3):
    showUsage()
#endIf 

if (sys.argv[0] != 'fullInstall'):
    if (sys.argv[0] != 'setupOnly'):
        showUsage()
    #endIf
#endif

if (sys.argv[0] == 'fullInstall'):
    if (len(sys.argv) < 5):
        showUsage()
    elif (len(sys.argv) > 5):
        showUsage()
    #endIf
#endif

if (sys.argv[0] == 'setupOnly'):
    if (len(sys.argv) > 3):
        showUsage()
    #endIf
#endif

#######################################################################

serverName = sys.argv[1]
nodeName = sys.argv[2]

if (sys.argv[0] == 'fullInstall'):
    blogEBA = sys.argv[3]
    JSON4JBundle = sys.argv[4]

print ""
print "Settings:"
print ""
print "--- serverName : " + serverName
print "--- nodeName : " + nodeName
if (sys.argv[0] == 'fullInstall'):
    print "--- blogEBA : " + blogEBA
    print "--- JSON4JBundle : " + JSON4JBundle
    print ""

########################################################################

def createIt(nodeName, serverName, name, jndiName, isJTA, databaseName):
    dsId = '/DataSource:' + name + '/'
    ds = AdminConfig.getid(dsId)
    if ds:
        print 'Datasource ' + name + ' already exists.'
        print ''
    else:
        jdbcProvider = AdminJDBC.createDataSource(nodeName, serverName, "Derby JDBC Provider (XA)", name, 
            [ ['connectionPool', [['maxConnections', 30]]],
            ['datasourceHelperClassname', 'com.ibm.websphere.rsadapter.DerbyDataStoreHelper'], 
            ['description', 'test Data source'], ['jndiName', jndiName], 
            ['propertySet', [['resourceProperties', [[['name', 'databaseName'], ['type', 'String'],
            ['value', databaseName]], [['name', 'nonTransactionalDataSource'], ['type', 'java.lang.Boolean'],
            ['value', isNonJTA]] ]]]]] )

#######################################################################

print "Creating JTA datasource:"
print ""
print "--- name : BlogDB"
print "--- jndiName : jdbc/blogdb"
print "--- isJTA : true"
print "--- databaseName : ${WAS_INSTALL_ROOT}/derby/BLOGDB"
print ""

name = "BlogDB"
jndiName = "jdbc/blogdb"
isNonJTA = "false"
databaseName = "${WAS_INSTALL_ROOT}/derby/BLOGDB"

createIt(nodeName, serverName, name, jndiName, isNonJTA, databaseName)

#######################################################################

print "Creating Non JTA datasource:"
print ""
print "--- name : BlogDBNonJTA"
print "--- jndiName : jdbc/blogdbnojta"
print "--- isJTA : false"
print "--- databaseName : ${WAS_INSTALL_ROOT}/derby/BLOGDB"
print ""

name = "BlogDBNonJTA"
jndiName = "jdbc/blogdbnojta"
isNonJTA = "true"

createIt(nodeName, serverName, name, jndiName, isNonJTA, databaseName)

#######################################################################

def installApp(nodeName, serverName, blogEBA, JSON4JBundle):
    print "Checking Internal Bundle Repository for com.ibm.json.java"
    jsonBundleName = 'com.ibm.json.java;1.0.0'

    localBundles = AdminTask.listLocalRepositoryBundles().splitlines()
    if jsonBundleName in localBundles:
        print "com.ibm.json.java already installed"
    else:
        print "Adding JSON4J to the Internal Bundle Repository"
        AdminTask.addLocalRepositoryBundle('[-file ' + JSON4JBundle + ']')
        AdminConfig.save()

    print ''
    
    print "Importing Asset:"
    blogSampleAssetId = 'WebSphere:assetname=com.ibm.ws.eba.example.blog.eba'
    assets = AdminTask.listAssets().splitlines()
    if blogSampleAssetId in assets:
        print '- Asset already exists.'
    else:
        AdminTask.importAsset(["-storageType", "FULL", "-source", blogEBA]) 
        AdminConfig.save()
        print "- Done"

        bcm = AdminControl.queryMBeans('type=BundleCacheManager,*')[0]
        bcmObjectName = bcm.getObjectName().toString()
        downloadsComplete = AdminControl.invoke(bcmObjectName, 'areAllDownloadsComplete')    

        loopCount = 0
        while downloadsComplete != 'true':
            sleep(1)
            downloadsComplete = AdminControl.invoke(bcmObjectName, 'areAllDownloadsComplete')
            loopCount += 1
            if loopCount == 150:
                print "- The bundle cache manager is indicating problems"
                bundles = AdminControl.invoke(bcmObjectName, 'getAllBundles').splitlines()
                for bundleName in bundles:
                    print bundleName + ' status: ' + AdminControl.invoke(bcmObjectName, 'getBundleDownloadState', bundleName)
                break

    print ""
    print "Creating Business Level Application:"
    blogSampleBlaId = 'WebSphere:blaname=Blog Sample'
    blas = AdminTask.listBLAs().splitlines()
    if blogSampleBlaId in blas:
        print '- Business Level Application already exists.'
    else:
        AdminTask.createEmptyBLA(['-name', 'Blog Sample', '-description', 'BLA for Blog Sample']) 
        print "- Done"
        print ""
        print "Creating Composition Unit:"
        AdminTask.addCompUnit(['-blaID', 'WebSphere:blaname=Blog Sample', '-cuSourceID', 'WebSphere:assetname=com.ibm.ws.eba.example.blog.eba', '-MapTargets', '[[ebaDeploymentUnit WebSphere:node=' + nodeName + ',server=' + serverName +']]'])
        print "- Done"

#######################################################################

if (sys.argv[0] == 'fullInstall'):
    installApp(nodeName, serverName, blogEBA, JSON4JBundle)
#endif

#######################################################################

AdminConfig.save()

nodeSync = AdminControl.completeObjectName('type=NodeSync,node='+nodeName+',*')
if nodeSync:
  AdminControl.invoke(nodeSync, 'sync')

if (sys.argv[0] == 'fullInstall'):
    AdminTask.startBLA(['-blaID', 'WebSphere:blaname=Blog Sample'])
#endif

print ""
print ""
print "--------------"
print "SETUP COMPLETE"
print "--------------"
