/*
 * @start_prolog@
 * ============================================================================
 *  Licensed Materials - Property of IBM
 *  
 *  5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70
 *  
 *  Copyright IBM Corp. 2009
 * ============================================================================
 * @end_prolog@
 * 
 * Change activity:
 * 
 * Issue       Date        Name           Description
 * ----------- ----------- -------------- ------------------------------------
 */
package com.ibm.ws.eba.example.blog.api;

import java.text.ParseException;
import java.util.List;

public interface BlogAuthorManager
{
  /**
   * Create an author.
   * @param email the author's email address, this is used as the key in the database
   * @param dob the author's date of birth
   * @param name the author's full name
   * @param displayName the author's display name
   * @param bio the author's biography
   * @throws ParseException
   */
  public void createAuthor(String email, String dob, String name, String displayName, String bio) throws ParseException;
  
  /**
   * Get all authors from the database.
   * @return a List<Author> of all authors in the database
   */
  public List<? extends BlogAuthor> getAllAuthors();
  
  /**
   * Get an individual author.
   * @param emailAddress - the email address of the author to retrieve
   * @return the author
   */
  public BlogAuthor getAuthor(String emailAddress);
  
  /**
   * Delete an author from the database.
   * @param emailAddress the email address of the author to delete
   */
  public void removeAuthor(String emailAddress);
  
  /**
   * Update a specific author with string date of birth
   * @param email the email address of the author being updated.
   * @param dob the new date of birth (as a string)
   * @param name the new full name
   * @param displayName the new display name
   * @param bio the new biography
   * @throws ParseException
   */
  public void updateAuthor(String email, String dob, String name, String displayName, String bio) throws ParseException;
  
}
