/*
 * @start_prolog@
 * ============================================================================
 *  Licensed Materials - Property of IBM
 *  
 *  5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70
 *  
 *  Copyright IBM Corp. 2009
 * ============================================================================
 * @end_prolog@
 * 
 * Change activity:
 * 
 * Issue       Date        Name     Description
 * ----------- ----------- -------- ------------------------------------
 */

package com.ibm.ws.eba.example.blog.comment.persistence.entity;

import java.util.Date;

import javax.persistence.Entity;
import javax.persistence.Table;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.ManyToOne;

import com.ibm.ws.eba.example.blog.comment.persistence.api.Comment;
import com.ibm.ws.eba.example.blog.persistence.entity.AuthorImpl;
import com.ibm.ws.eba.example.blog.persistence.entity.EntryImpl;

/**
 * This class represents a blog Comment post
 */
@Entity(name="COMMENT")
@Table(name="COMMENT")
public class CommentImpl implements Comment
{
  /** Many comments by one Author */
  @ManyToOne(fetch = FetchType.EAGER)
  private AuthorImpl author;
  
  /** Many comments to one blog entry */
  @ManyToOne(fetch = FetchType.EAGER)
  private EntryImpl blogentry;
  
  /** The comment */
  private String comment;
  
  /** Posting date of the comment */
  private Date creationDate;
  
  /** The database key for each comment */
  @Id
  @GeneratedValue
  private int id;

  /**
   * Get the author of this comment
   * @return the author
   */
  public AuthorImpl getAuthor()
  {
    return author;
  }

  /**
   * Get the blog entry associated with this comment
   * @return the blog entry
   */
  public EntryImpl getEntry()
  {
    return blogentry;
  }

  /**
   * Get the comment text
   * @return the comment text
   */
  public String getComment()
  {
    return comment;
  }

  /**
   * Get the creation date of this comment
   * @return the creation date
   */
  public Date getCreationDate()
  {
    return creationDate;
  }

  /**
   * Get this comments database Id key
   * @return the int value
   */
  public int getId()
  {
    return id;
  }

  
  /**
   * Set the author of this comment
   * @param a the author
   */
  public void setAuthor(AuthorImpl a)
  {
    author =  a;
  }
  
  /**
   * Set the blog entry this comment is associated with
   * @param b - the blog entry
   */
  public void setEntry(EntryImpl b)
  {
    blogentry = b;
  }
  
  /**
   * Set the text of this comment
   * @param comment the comment text
   */
  public void setComment(String comment)
  {
    this.comment = comment;
  }
  
  /**
   * Set this comments creation date
   * @param creationDate the date of creation
   */
  public void setCreationDate(Date creationDate)
  {
    this.creationDate = creationDate;
  }
}
