/*
 * @start_prolog@
 * ============================================================================
 *  Licensed Materials - Property of IBM
 *  
 *  5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70
 *  
 *  Copyright IBM Corp. 2009
 * ============================================================================
 * @end_prolog@
 * 
 * Change activity:
 * 
 * Issue       Date        Name           Description
 * ----------- ----------- -------------- ------------------------------------
 */
package com.ibm.ws.eba.example.blog.persistence.entity;

import java.util.Date;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

import com.ibm.ws.eba.example.blog.persistence.api.Entry;

/**
 * This class represents a blog entry
 */
@Entity(name = "BLOGENTRY")
@Table(name = "BLOGENTRY")
public class EntryImpl implements Entry
{
  /** An auto-generated primary key */
  @Id
  @GeneratedValue
  private long id;
  
  /** The author of the blog post */
  @ManyToOne(fetch = FetchType.EAGER)
  private AuthorImpl author;
  
  /** The date the post was published */
  private Date publishDate;
  /** The date the post was last updated */
  private Date updatedDate;
  /** The title of the post */
  private String title;
  /** Tags associated with the post */
  private List<String> tags;
  /** The text of the blog */
  @Column(length=10000)
  private String blogText;
  
  /** Get the author of this blog post */
  public AuthorImpl getAuthor()
  {
    return author;
  }
  
  /** Get the publish date of this blog post */
  public Date getPublishDate()
  {
    return publishDate;
  }
  
  /** Get the title of this blog post */
  public String getTitle()
  {
    return title;
  }
  
  /** Get the tags for this blog post */
  public List<String> getTags()
  {
    return tags;
  }
 
  
  /** Get the text for this blog post */
  public String getBlogText()
  {
    return blogText;
  }
  

  /** get the Blog post id */
  public long getId()
  {
    return id;
  }

  /**
   * @return The date of the last update to this blog
   *         or null if it has never been modified
   */
  public Date getUpdatedDate()
  {
    return updatedDate;
  }
  
  
  //set methods are only defined in implementation class. Not part of interface.
  
  
  /** Set the author of this blog post */
  public void setAuthor(AuthorImpl author)
  {
    this.author = author;
  }
  
  
  /** Set the publish date of this blog post */
  public void setPublishDate(Date publishDate)
  {
    this.publishDate = publishDate;
  }
  
  /** Set the title of this blog post */
  public void setTitle(String title)
  {
    this.title = title;
  }
  
  /** Set the text for this blog post */
  public void setBlogText(String blogText)
  {
    this.blogText = blogText;
  }
  
  
  /** Set the tags for this blog post */
  public void setTags(List<String> tags)
  {
    this.tags = tags;
  }

  /**
   * Set the date that the blog post was last updated
   * 
   * @param updatedDate
   */
  public void setUpdatedDate(Date updatedDate)
  {
    this.updatedDate = updatedDate;
  }
  
}
