/*
 * @start_prolog@
 * ============================================================================
 *  Licensed Materials - Property of IBM
 *  
 *  5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70
 *  
 *  Copyright IBM Corp. 2009
 * ============================================================================
 * @end_prolog@
 * 
 * Change activity:
 * 
 * Issue       Date        Name           Description
 * ----------- ----------- -------------- ------------------------------------
 */
package com.ibm.ws.eba.example.blog.web;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.http.HttpServletRequest;

import com.ibm.ws.eba.example.blog.api.BlogAuthor;
import com.ibm.ws.eba.example.blog.api.BloggingService;
import com.ibm.ws.eba.example.blog.web.util.FormServlet;
import com.ibm.ws.eba.example.blog.web.util.HTMLOutput;
import com.ibm.ws.eba.example.blog.web.util.JNDIHelper;

public class EditAuthorForm extends FormServlet
{
  private static final long serialVersionUID = 4996935653835900015L;
  public static final String ID = "author";

  public EditAuthorForm()
  {
    super(ID);
  }
  
  @Override
  protected void writeCustomHeaderContent(HttpServletRequest req, PrintWriter out)
  {
    HTMLOutput.writeDojoUses(out, "dijit.form.TextBox", "dijit.form.DateTextBox", "dijit.form.Textarea");
  }

  @Override
  protected String getPageTitle(HttpServletRequest req) throws IOException
  {
    String pageTitle = "Create Author";
    
    BloggingService service = JNDIHelper.getBloggingService();
    String email = getEmail(req);
    
    if (email != null && !!!"".equals(email)) {
      BlogAuthor author = service.getBlogAuthor(email);
      if (author != null) {
        pageTitle = "Update " + author.getName() + "'s profile";
      }
    }
    
    return pageTitle;
  }

  private String getEmail(HttpServletRequest req)
  {
    String email = retrieveOrEmpty(req, "email");
    if ("".equals(email)) {
      email = req.getParameter("email");
    }
    return checkEmail(email);
  }
  
  @Override
  protected void writeForm(HttpServletRequest req, PrintWriter out) throws IOException
  {
    String name = retrieveOrEmpty(req, "name");
    String nickName = retrieveOrEmpty(req, "nickName");
    String bio = retrieveOrEmpty(req, "bio");
    String dob = retrieveOrEmpty(req, "dob");
    String email = getEmail(req);
    
    BloggingService service = JNDIHelper.getBloggingService();
    
    if (email != null && !!!"".equals(email)) {
      BlogAuthor author = service.getBlogAuthor(email);
      
      if ("".equals(name))
        name = author.getFullName();
      if ("".equals(nickName))
        nickName = author.getName();
      if ("".equals(bio))
        bio = author.getBio();
      if ("".equals(dob))
        dob = author.getDateOfBirth();
    } else {
      email = "";
    }
    
    out.println("<form method=\"get\" action=\"EditAuthor\">");
    
    out.print("<div class=\"textEntry\"><label>Name <input dojoType=\"dijit.form.TextBox\" type=\"text\" name=\"name\" value=\"");
    out.print(name);
    out.println("\"/></label></div>");
    out.print("<div class=\"textEntry\"><label>Nick Name <input dojoType=\"dijit.form.TextBox\" type=\"text\" name=\"nickName\" value=\"");
    out.print(nickName);
    out.println("\"/></label></div>");
    out.print("<div class=\"textEntry\"><label>Email <input dojoType=\"dijit.form.TextBox\" type=\"text\" name=\"email\" value=\"");
    out.print(email);
    out.println("\"/></label></div>");
    out.print("<div class=\"textEntry\"><label>Date of Birth <input dojoType=\"dijit.form.DateTextBox\" type=\"text\" name=\"dob\" required=\"true\" value=\"");
    out.print(dob);
    out.println("\"/></label></div>");
    out.print("<div class=\"textEntry\"><label>Bio <textarea dojoType=\"dijit.form.Textarea\" style=\"width:300px\" name=\"bio\">");
    out.print(bio);
    out.println("</textarea></label></div>");

    out.println("<input class=\"submit\" type=\"submit\" value=\"Submit\" name=\"Submit\"/>");
    
    out.println("</form>");
  }
  
  private String checkEmail(String parameter)
  {
    if (parameter != null && parameter.matches("^(?:[a-zA-Z0-9_'^&amp;/+-])+(?:\\.(?:[a-zA-Z0-9_'^&amp;/+-])+)*@(?:(?:\\[?(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?))\\.){3}(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\]?)|(?:[a-zA-Z0-9-]+\\.)+(?:[a-zA-Z]){2,}\\.?)$")) return parameter;
    return null;
  }
}