/*
 * @start_prolog@
 * ============================================================================
 *  Licensed Materials - Property of IBM
 *  
 *  5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70
 *  
 *  Copyright IBM Corp. 2009
 * ============================================================================
 * @end_prolog@
 * 
 * Change activity:
 * 
 * Issue       Date        Name           Description
 * ----------- ----------- -------------- ------------------------------------
 */
package com.ibm.ws.eba.example.blog;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import com.ibm.ws.eba.example.blog.api.BlogAuthor;
import com.ibm.ws.eba.example.blog.api.BlogAuthorManager;
import com.ibm.ws.eba.example.blog.persistence.api.Author;
import com.ibm.ws.eba.example.blog.persistence.api.BlogPersistenceService;

public class BlogAuthorManagerImpl implements BlogAuthorManager {
	private BlogPersistenceService persistenceService;

	// Blueprint injection used to set the persistenceService
	public void setPersistenceService(BlogPersistenceService persistenceService) {
		this.persistenceService = persistenceService;
	}

	public void createAuthor(String email, String dob, String name,
			String displayName, String bio) throws ParseException {
		if (email == null)
			throw new IllegalArgumentException("Email must not be null");
		
		Date dateOfBirth = null;
		
		try {
			if (dob == null || "".equals(dob)) {
				dateOfBirth = null;
			} else {
				dateOfBirth = new SimpleDateFormat("yyyy-MM-dd").parse(dob);
			}
		} catch (ParseException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		persistenceService.createAuthor(email, dateOfBirth, name, displayName, bio);
	}

	public List<? extends BlogAuthor> getAllAuthors() {
		List<? extends Author> authors = persistenceService.getAllAuthors();
		return adaptAuthor(authors);
	}

	public BlogAuthor getAuthor(String emailAddress) {
		if (emailAddress == null)
			throw new IllegalArgumentException("Email must not be null");
		Author a = persistenceService.getAuthor(emailAddress);
		if (a != null)
			return new BlogAuthorImpl(a);
		else
			return null;
	}

	public void removeAuthor(String emailAddress) {
		if (emailAddress == null)
			throw new IllegalArgumentException("Email must not be null");
		persistenceService.removeAuthor(emailAddress);
	}

	public void updateAuthor(String email, String dob, String name,
			String displayName, String bio) throws ParseException {
		
		if (email == null)
			throw new IllegalArgumentException("Email must not be null");

		Date dateOfBirth = (dob == null) ? null : new SimpleDateFormat(
				"yyyy-MM-dd").parse(dob);
		persistenceService.updateAuthor(email, dateOfBirth, name, displayName, bio);
	}

	private List<? extends BlogAuthor> adaptAuthor(
			List<? extends Author> authors) {
			return new BlogListAdapter<BlogAuthor, Author>(authors, BlogAuthorImpl.class, Author.class);

	}
}

