/*
 * @start_prolog@
 * ============================================================================
 *  Licensed Materials - Property of IBM
 *  
 *  5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70
 *  
 *  Copyright IBM Corp. 2009
 * ============================================================================
 * @end_prolog@
 * 
 * Change activity:
 * 
 * Issue       Date        Name           Description
 * ----------- ----------- -------------- ------------------------------------
 */
package com.ibm.ws.eba.example.blog;
import java.util.Calendar;
import java.util.Date;

import com.ibm.ws.eba.example.blog.api.BlogAuthor;
import com.ibm.ws.eba.example.blog.api.BlogComment;
import com.ibm.ws.eba.example.blog.api.BlogEntry;
import com.ibm.ws.eba.example.blog.comment.persistence.api.Comment;

public  class BlogCommentImpl implements BlogComment
{
	private static Calendar cal = Calendar.getInstance();
	
	private Comment comment;
	
	public BlogCommentImpl(Comment c) {
		 comment = c;
	}
  /** Get comment 
   *  @return the String representing the comment 
   */
  public String getComment() {
	  return comment.getComment();
  }
  
  /** Get the author of the comment 
   *  @return the BlogAuthor instance 
   */
  public BlogAuthor getAuthor() {
	  return new BlogAuthorImpl(comment.getAuthor());
  }
  
  /** Get the parent blog post for the comment 
   *  @return the BlogPost instance the comment is attached to.  
   */
  public BlogEntry getEntry() {
	  return new BlogEntryImpl(comment.getEntry());
  }

  /** Get the Id value of the comment 
   *  @return the integer id of the comment 
   */
  public int getId() {
	  return comment.getId();
  }
  
  /** Get the creation date for the comment 
   *  @return the String representation of the date the comment was
   *  created in dd-mm-yyyy format. 
   */
  public String getCommentCreationDate() {
	  
	  Date dc = comment.getCreationDate();
	  int year;
		int month;
		int date;

		synchronized (cal) {
			cal.setTime(dc);
			year = cal.get(Calendar.YEAR);
			month = cal.get(Calendar.MONTH) + 1;
			date = cal.get(Calendar.DATE);
		}

		return year + "-" + month + "-" + date;

  }
  
}
