package com.ibm.ws.eba.example.blog;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import com.ibm.ws.eba.example.blog.api.BlogAuthor;
import com.ibm.ws.eba.example.blog.api.BlogComment;
import com.ibm.ws.eba.example.blog.api.BlogCommentManager;
import com.ibm.ws.eba.example.blog.comment.persistence.api.BlogCommentService;
import com.ibm.ws.eba.example.blog.comment.persistence.api.Comment;
import com.ibm.ws.eba.example.blog.persistence.api.Author;

public class BlogCommentManagerImpl implements BlogCommentManager{
	
	private BlogCommentService commentService;
	private boolean commentServiceValid;
	
	// Injected via blueprint
	public void setCommentService(BlogCommentService bcs) {
		commentService = bcs;
	}


	public void createComment(String comment, String email, long entryId) {
		commentService.createComment(comment, email, entryId);
	}

	public List<? extends BlogComment> getCommentsByAuthor(String email) {
		List<? extends Comment> comment = commentService.getCommentsForAuthor(email);
		return adaptComment(comment);
		
	}		

	public List<? extends BlogComment> getCommentsForPost(long id) {
		List<? extends Comment> comment = commentService.getCommentsForEntry(id);
		return adaptComment(comment);
	}
		

	public void deleteComment(int id) {
		commentService.delete(id);
	}

	private List<? extends BlogComment> adaptComment(
			List<? extends Comment> comments) {
		
		if(comments.isEmpty())
			return new ArrayList<BlogComment>();
		else
			return new BlogListAdapter<BlogComment, Comment>(comments, BlogCommentImpl.class, Comment.class);

	}
	
	public boolean isCommentingAvailable() {
		return commentServiceValid;
	}
	
	public void blogServiceBound(BlogCommentService comment, Map props) {
		commentServiceValid = true;
	}

	public void blogServiceUnbound(BlogCommentService comment, Map props) {

	}
}
