/*
 * @start_prolog@
 * ============================================================================
 *  Licensed Materials - Property of IBM
 *  
 *  5724-J08, 5724-I63, 5724-H88, 5724-H89, 5655-N02, 5733-W70
 *  
 *  Copyright IBM Corp. 2009
 * ============================================================================
 * @end_prolog@
 * 
 * Change activity:
 * 
 * Issue       Date        Name           Description
 * ----------- ----------- -------------- ------------------------------------
 */
package com.ibm.ws.eba.example.blog;

import java.text.ParseException;
import java.util.Arrays;
import java.util.List;

import com.ibm.ws.eba.example.blog.api.BlogAuthor;
import com.ibm.ws.eba.example.blog.api.BlogAuthorManager;
import com.ibm.ws.eba.example.blog.api.BlogComment;
import com.ibm.ws.eba.example.blog.api.BlogCommentManager;
import com.ibm.ws.eba.example.blog.api.BlogEntry;
import com.ibm.ws.eba.example.blog.api.BlogEntryManager;
import com.ibm.ws.eba.example.blog.api.BloggingService;

/** Implementation of the BloggingService */
public class BloggingServiceImpl implements BloggingService {
	private BlogEntryManager blogEntryManager;
	private BlogAuthorManager blogAuthorManager;
	private BlogCommentManager blogCommentManager;

	// Injected via blueprint
	public void setBlogEntryManager(BlogEntryManager blogEntryManager) {
		this.blogEntryManager = blogEntryManager;
	}

	// Injected via blueprint
	public void setBlogAuthorManager(BlogAuthorManager blogAuthorManager) {
		this.blogAuthorManager = blogAuthorManager;
	}

	// Injected via blueprint
	public void setBlogCommentManager(BlogCommentManager blogCommentManager) {
		this.blogCommentManager = blogCommentManager;
	}

	public String getBlogTitle() {
		return new BlogImpl().getBlogTitle();
	}

	public BlogAuthor getBlogAuthor(String email) {
		return blogAuthorManager.getAuthor(email);

	}

	public void createBlogAuthor(String email, String nickName, String name,
			String bio, String dob) {
		try {
			blogAuthorManager.createAuthor(email, dob, name, nickName, bio);
		} catch (ParseException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	public void updateBlogAuthor(String email, String nickName, String name,
			String bio, String dob) {
		try {
			blogAuthorManager.updateAuthor(email, dob, name, nickName, bio);
		} catch (ParseException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	public void createBlogEntry(String email, String title, String blogText,
			String tags) {
		blogEntryManager.createBlogPost(email, title, blogText, Arrays
				.asList(tags.split(",")));
	}

	public void createBlogComment(String comment, String authorEmail, long id) {
		blogCommentManager.createComment(comment, authorEmail, id);
	}

	public void deleteBlogComment(BlogComment comment) {
		blogCommentManager.deleteComment(comment.getId());
	}

	public List<? extends BlogComment> getCommentsForEntry(BlogEntry entry) {
		return blogCommentManager.getCommentsForPost(entry.getId());
	}

	public BlogEntry getBlogEntry(long id) {
		return blogEntryManager.getBlogPost(id);
	}

	public boolean isCommentingAvailable() {
		return blogCommentManager.isCommentingAvailable();

	}

	public int getNoOfEntries() {
		return blogEntryManager.getNoOfPosts();
	}

	public List<? extends BlogEntry> getBlogEntries(int firstPostIndex,
			int noOfPosts) {
		return blogEntryManager.getBlogEntries(firstPostIndex, noOfPosts);

	}

	public List<? extends BlogEntry> getAllBlogEntries() {
		return blogEntryManager.getAllBlogEntries();
	}
}